.. _install:
.. highlight:: shell

Installation
============

Stable Release
--------------

To install time2relax, run this command in your terminal::

    $ pip install -U time2relax

This is the preferred method to install time2relax, as it will always install
the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/

From Sources
------------

The sources for time2relax can be downloaded from the `Github repo`_.

You can either clone the public repository::

    $ git clone git://github.com/rwanyoike/time2relax

Or download the `tarball`_::

    $ curl -OL https://github.com/rwanyoike/time2relax/tarball/master

Once you have a copy of the source, you can install it with::

    $ python setup.py install

.. _Github repo: https://github.com/rwanyoike/time2relax
.. _tarball: https://github.com/rwanyoike/time2relax/tarball/master
